@@ -19,6 +19,7 @@
 #include "../cstream.h"
 #include "../detail/uiviewcreatorattributes.h"
 #include "../../lib/cvstguitimer.h"
+#include "../../lib/cexternalview.h"
 #include "../../lib/cframe.h"
 #include "../../lib/cscrollview.h"
 #include "../../lib/cdropsource.h"
@@ -33,7 +34,7 @@
 namespace VSTGUI {
 
 namespace UIEditViewInternal {
-	
+
 //----------------------------------------------------------------------------------------------------
 class UISelectionView : public UIOverlayView, public UISelectionListenerAdapter
 //----------------------------------------------------------------------------------------------------
@@ -205,8 +206,67 @@ void UIHighlightView::draw (CDrawContext* pContext)
 	pContext->drawRect (r, kDrawFilledAndStroked);
 }
 
+//------------------------------------------------------------------------
+template<typename T>
+void collectExternalViewsOnInlineEditing (CViewContainer* container, T& array)
+{
+	container->forEachChild ([&] (auto view) {
+		if (view.template cast<ExternalView::IViewEmbedder> ())
+			array.emplace_back (view);
+		else if (auto c = view->asViewContainer ())
+			collectExternalViewsOnInlineEditing (c, array);
+	});
+}
+
 } // UIEditViewInternal
 
+//------------------------------------------------------------------------
+struct UIEditView::ViewAddedObserver : IViewAddedRemovedObserver,
+									   ViewListenerAdapter
+{
+	~ViewAddedObserver () override
+	{
+		for (auto view : views)
+		{
+			if (auto viewEmbedder = dynamic_cast<ExternalView::IViewEmbedder*> (view))
+			{
+				if (auto ev = viewEmbedder->getExternalView ())
+					ev->setMouseEnabled (view->getMouseEnabled ());
+			}
+			view->unregisterViewListener (this);
+		}
+	}
+	void onViewAdded (CFrame* frame, CView* view) override
+	{
+		if (auto viewEmbedder = dynamic_cast<ExternalView::IViewEmbedder*> (view))
+		{
+			if (auto ev = viewEmbedder->getExternalView ())
+				ev->setMouseEnabled (false);
+			view->registerViewListener (this);
+			views.emplace_back (view);
+		}
+	}
+	void onViewRemoved (CFrame* frame, CView* view) override {}
+
+	void viewWillDelete (CView* view) override
+	{
+		view->unregisterViewListener (this);
+		auto it = std::find (views.begin (), views.end (), view);
+		if (it != views.end ())
+			views.erase (it);
+	}
+	void viewOnMouseEnabled (CView* view, bool state) override
+	{
+		if (auto viewEmbedder = dynamic_cast<ExternalView::IViewEmbedder*> (view))
+		{
+			if (auto ev = viewEmbedder->getExternalView ())
+				ev->setMouseEnabled (false);
+		}
+	}
+
+	std::vector<CView*> views;
+};
+
 //----------------------------------------------------------------------------------------------------
 //----------------------------------------------------------------------------------------------------
 //----------------------------------------------------------------------------------------------------
@@ -274,7 +334,7 @@ void UIEditView::enableEditing (bool state)
 		CFrame* parent = getFrame ();
 		if (parent == nullptr)
 			return;
-		
+
 		if (editing)
 		{
 			CRect r = parent->getViewSize ();
@@ -286,7 +346,7 @@ void UIEditView::enableEditing (bool state)
 			overlayView->setTransparency (true);
 			overlayView->setZIndex (std::numeric_limits<uint32_t>::max () - 1);
 			parent->addView (overlayView);
-			
+
 			highlightView = new UIEditViewInternal::UIHighlightView (this, viewHighlightColor);
 			overlayView->addView (highlightView);
 			auto selectionView = new UIEditViewInternal::UISelectionView (this, getSelection (), viewSelectionColor, kResizeHandleSize);
@@ -299,6 +359,25 @@ void UIEditView::enableEditing (bool state)
 			highlightView = nullptr;
 			lines = nullptr;
 		}
+		disableExternalViewsOnInlineEditing (editing);
+	}
+}
+
+//------------------------------------------------------------------------
+void UIEditView::disableExternalViewsOnInlineEditing (bool state)
+{
+	CFrame* parent = getFrame ();
+	if (editingViewAddedObserver)
+		parent->setViewAddedRemovedObserver (nullptr);
+	editingViewAddedObserver.reset ();
+	if (state)
+	{
+		editingViewAddedObserver = std::make_unique<ViewAddedObserver> ();
+		std::vector<CView*> views;
+		UIEditViewInternal::collectExternalViewsOnInlineEditing (this, views);
+		for (auto* v : views)
+			editingViewAddedObserver->onViewAdded (parent, v);
+		parent->setViewAddedRemovedObserver (editingViewAddedObserver.get ());
 	}
 }
 
@@ -349,6 +428,7 @@ void UIEditView::setEditView (CView* view)
 {
 	if (view != getEditView ())
 	{
+		disableExternalViewsOnInlineEditing (false);
 		invalid ();
 		removeAll ();
 		CRect vs (getViewSize ());
@@ -364,6 +444,7 @@ void UIEditView::setEditView (CView* view)
 			setMouseableArea (vs);
 			setViewSize (vs);
 		}
+		disableExternalViewsOnInlineEditing (editing);
 		invalid ();
 	}
 }
@@ -421,7 +502,7 @@ void UIEditView::drawRect (CDrawContext *pContext, const CRect& updateRect)
 
 	if (!editing && focusDrawing)
 		getFrame ()->setFocusDrawingEnabled (focusDrawing);
-	
+
 	pContext->setClipRect (updateRect);
 
 	CDrawContext::Transform transform (*pContext, CGraphicsTransform ().translate (getViewSize ().left, getViewSize ().top));
@@ -1342,6 +1423,12 @@ bool UIEditView::attached (CView* parent)
 //-----------------------------------------------------------------------------
 bool UIEditView::removed (CView* parent)
 {
+	auto frame = getFrame ();
+	if (editingViewAddedObserver)
+	{
+		frame->setViewAddedRemovedObserver (nullptr);
+		editingViewAddedObserver.reset ();
+	}
 	IController* controller = getViewController (this, true);
 	if (controller)
 	{
@@ -1351,9 +1438,10 @@ bool UIEditView::removed (CView* parent)
 	}
 	if (overlayView)
 	{
-		getFrame()->removeView (overlayView);
+		frame->removeView (overlayView);
 		overlayView = nullptr;
 	}
+	frame->setCursor (kCursorDefault);
 	return CViewContainer::removed (parent);
 }
 
